@@ -160,11 +160,6 @@ class FileLocations(object):
         OVIRT_HOSTED_ENGINE,
         'vm.conf'
     )
-    GLUSTERD_VOL = os.path.join(
-        SYSCONFDIR,
-        'glusterfs',
-        'glusterd.vol'
-    )
     OVIRT_APPLIANCES_DESC_DIR = os.path.join(
         config.SYSCONFDIR,
         OVIRT_HOSTED_ENGINE,
@@ -327,7 +322,6 @@ class FileLocations(object):
 class Const(object):
     MINIMUM_SPACE_STORAGEDOMAIN_MB = 20480
     FIRST_HOST_ID = 1
-    GLUSTERD_SERVICE = 'glusterd'
     HA_AGENT_SERVICE = 'ovirt-ha-agent'
     HA_BROCKER_SERVICE = 'ovirt-ha-broker'
     HOSTED_ENGINE_VM_NAME = 'HostedEngine'
@@ -358,6 +352,8 @@ class Const(object):
     VIRTIO_PORTS_PATH = '/dev/virtio-ports/'
     E_SETUP_SUCCESS_STRING = 'HE_APPLIANCE_ENGINE_SETUP_SUCCESS'
     E_SETUP_FAIL_STRING = 'HE_APPLIANCE_ENGINE_SETUP_FAIL'
+    E_RESTORE_SUCCESS_STRING = 'HE_APPLIANCE_ENGINE_RESTORE_SUCCESS'
+    E_RESTORE_FAIL_STRING = 'HE_APPLIANCE_ENGINE_RESTORE_FAIL'
     # sync with engine table storage_server_connections
     # (packaging/dbscripts/create_tables.sql)
     MAX_STORAGE_USERNAME_LENGTH = 50
@@ -373,6 +369,7 @@ class CoreEnv(object):
     REQUIREMENTS_CHECK_ENABLED = 'OVEHOSTED_CORE/checkRequirements'
     ADDITIONAL_HOST_ENABLED = 'OVEHOSTED_CORE/additionalHostEnabled'
     IS_ADDITIONAL_HOST = 'OVEHOSTED_CORE/isAdditionalHost'
+    UPGRADING_APPLIANCE = 'OVEHOSTED_CORE/upgradingAppliance'
     TEMPDIR = 'OVEHOSTED_CORE/tempDir'
 
     @ohostedattrs(
@@ -381,6 +378,12 @@ class CoreEnv(object):
     def DEPLOY_PROCEED(self):
         return 'OVEHOSTED_CORE/deployProceed'
 
+    @ohostedattrs(
+        answerfile=True,
+    )
+    def UPGRADE_PROCEED(self):
+        return 'OVEHOSTED_CORE/upgradeProceed'
+
     @ohostedattrs(
         answerfile=True,
     )
@@ -470,6 +473,7 @@ class NetworkEnv(object):
 class EngineEnv(object):
 
     ADMIN_PASSWORD = 'OVEHOSTED_ENGINE/adminPassword'
+    INTERACTIVE_ADMIN_PASSWORD = 'OVEHOSTED_ENGINE/interactiveAdminPassword'
 
     @ohostedattrs(
         summary=True,
@@ -591,30 +595,6 @@ class StorageEnv(object):
     def MNT_OPTIONS(self):
         return 'OVEHOSTED_STORAGE/mntOptions'
 
-    @ohostedattrs(
-        answerfile=True,
-        summary=True,
-        description=_('GlusterFS Brick Provisioning'),
-    )
-    def GLUSTER_PROVISIONING_ENABLED(self):
-        return 'OVEHOSTED_STORAGE/glusterProvisioningEnabled'
-
-    @ohostedattrs(
-        answerfile=True,
-        summary=True,
-        description=_('GlusterFS Brick'),
-    )
-    def GLUSTER_BRICK(self):
-        return 'OVEHOSTED_STORAGE/glusterBrick'
-
-    @ohostedattrs(
-        answerfile=True,
-        summary=True,
-        description=_('GlusterFS Share Name'),
-    )
-    def GLUSTER_SHARE_NAME(self):
-        return 'OVEHOSTED_STORAGE/glusterProvisionedShareName'
-
     @ohostedattrs(
         answerfile=True,
         summary=True,
@@ -798,6 +778,13 @@ class VMEnv(object):
     def OVF(self):
         return 'OVEHOSTED_VM/ovfArchive'
 
+    @ohostedattrs(
+        summary=True,
+        description=_('Appliance version'),
+    )
+    def APPLIANCE_VERSION(self):
+        return 'OVEHOSTED_VM/applianceVersion'
+
     VM_PASSWD = 'OVEHOSTED_VDSM/passwd'
     VM_PASSWD_VALIDITY_SECS = 'OVEHOSTED_VDSM/passwdValiditySecs'
     SUBST = 'OVEHOSTED_VM/subst'
@@ -958,11 +945,11 @@ class Stages(object):
     CONFIG_STORAGE_BLOCKD = 'ohosted.storage.blockd.configuration.available'
     CONFIG_STORAGE_NFS = 'ohosted.storage.nfs.configuration.available'
     CONFIG_GATEWAY = 'ohosted.networking.gateway.configuration.available'
-    GLUSTER_PROVISIONING = 'ohosted.storage.gluster.provisioned'
     CONFIG_ADDITIONAL_HOST = 'ohosted.core.additional.host'
     CONFIG_CLOUD_INIT_OPTIONS = 'ohosted.boot.configuration.cloud_init_options'
     CONFIG_CLOUD_INIT_VM_NETWORKING = \
         'ohosted.boot.configuration.cloud_init_vm_networking'
+    CONFIG_BACKUP_FILE = 'ohosted.configuration.backupfile'
     REQUIRE_ANSWER_FILE = 'ohosted.core.require.answerfile'
     CONFIG_OVF_IMPORT = 'ohosted.configuration.ovf'
     VDSMD_START = 'ohosted.vdsm.started'
@@ -974,9 +961,11 @@ class Stages(object):
     IMAGES_REPREPARED = 'ohosted.storage.imagesreprepared'
     VM_IMAGE_AVAILABLE = 'ohosted.vm.image.available'
     OVF_IMPORTED = 'ohosted.vm.ovf.imported'
+    BACKUP_INJECTED = 'ohosted.vm.backup.injected'
     STORAGE_POOL_DESTROYED = 'ohosted.storage.pool.destroyed'
     VM_CONFIGURED = 'ohosted.vm.state.configured'
     VM_RUNNING = 'ohosted.vm.state.running'
+    VM_SHUTDOWN = 'ohosted.vm.state.shutdown'
     BRIDGE_AVAILABLE = 'ohosted.network.bridge.available'
     LIBVIRT_CONFIGURED = 'ohosted.libvirt.configured'
     SAVE_CONFIG = 'ohosted.save.config'
@@ -988,6 +977,8 @@ class Stages(object):
         'ohosted.network.firewallmanager.available'
     NET_FIREWALL_MANAGER_PROCESS_TEMPLATES = \
         'ohosted.network.firewallmanager.templates.available'
+    NET_FIREWALL_FIRST_STAGE_CONFIGURED = \
+        'ohosted.network.firewallmanager.fsconfigured'
     VDSMD_CONF_LOADED = 'ohosted.vdsm.conf.loaded'
     HOST_ADDED = 'ohosted.engine.host.added'
     VDSCLI_RECONNECTED = 'ohosted.engine.vdscli.reconnected'
@@ -1000,6 +991,16 @@ class Stages(object):
     BROKER_CONF_AVAILABLE = 'ohosted.notifications.broker.conf.available'
     ANSWER_FILE_AVAILABLE = 'ohosted.notifications.answerfile.available'
     CONF_IMAGE_AVAILABLE = 'ohosted.notifications.confimage.available'
+    UPGRADED_APPLIANCE_RUNNING = 'ohosted.vm.state.upgraded.appliance.running'
+    CHECK_MAINTENANCE_MODE = 'ohosted.core.check.maintenance.mode'
+    VALIDATION_CA_ACQUIRED = 'ohosted.engine.ca.acquired.validation'
+    CLOSEUP_CA_ACQUIRED = 'ohosted.engine.ca.acquired.closeup'
+    CLOSEUP_CA_ACQUIRED = 'ohosted.engine.ca.acquired.closeup'
+    UPGRADE_CHECK_SD_SPACE = 'ohosted.upgrade.check.sd.space'
+    UPGRADE_DISK_CREATED = 'ohosted.upgrade.disk.created'
+    UPGRADE_VM_SHUTDOWN = 'ohosted.upgrade.vm.state.shutdown'
+    UPGRADED_DISK_SWITCHED = 'ohosted.upgrade.vm.disk.switched'
+    UPGRADED_DATACENTER_UP = 'ohosted.upgrade.datacenter.up'
 
     DIALOG_TITLES_S_VM = 'ohosted.dialog.titles.vm.start'
     DIALOG_TITLES_E_VM = 'ohosted.dialog.titles.vm.end'
@@ -1016,7 +1017,6 @@ class Stages(object):
 @util.export
 @util.codegen
 class Defaults(object):
-    DEFAULT_GLUSTER_SHARE_NAME = 'hosted_engine_glusterfs'
     DEFAULT_STORAGE_DOMAIN_NAME = 'hosted_storage'
     DEFAULT_STORAGE_DATACENTER_NAME = 'hosted_datacenter'
     DEFAULT_VDSMD_SERVICE = 'vdsmd'
@@ -1034,7 +1034,7 @@ class Defaults(object):
     DEFAULT_BRIDGE_NAME = 'ovirtmgmt'
     DEFAULT_PKI_SUBJECT = '/C=EN/L=Test/O=Test/CN=Test'
     DEFAULT_CA_SUBJECT = '/C=EN/L=Test/O=Test/CN=TestCA'  # must be != above
-    DEFAULT_VM_PASSWD_VALIDITY_SECS = "10800"  # 3 hours to for engine install
+    DEFAULT_VM_PASSWD_VALIDITY_SECS = 10800  # 3 hours to for engine install
     DEFAULT_VM_VCPUS = 2  # based on minimum requirements.
     DEFAULT_SSHD_PORT = 22
     DEFAULT_EMULATED_MACHINE = 'pc'
@@ -1049,6 +1049,7 @@ class Defaults(object):
 @util.codegen
 class Confirms(object):
     DEPLOY_PROCEED = 'DEPLOY_PROCEED'
+    UPGRADE_PROCEED = 'UPGRADE_PROCEED'
     CPU_PROCEED = 'CPU_PROCEED'
     DISK_PROCEED = 'DISK_PROCEED'
     MEMORY_PROCEED = 'MEMORY_PROCEED'
@@ -1063,4 +1064,16 @@ class FirstHostEnv(object):
     DEPLOY_WITH_HE_35_HOSTS = 'OVEHOSTED_FIRST_HOST/deployWithHE35Hosts'
 
 
+@util.export
+@util.codegen
+class Upgrade(object):
+    BACKUP_FILE = 'OVEHOSTED_UPGRADE/backupFileName'
+    RESTORE_DWH = 'OVEHOSTED_UPGRADE/restoreDwh'
+    RESTORE_REPORTS = 'OVEHOSTED_UPGRADE/restoreReports'
+    CONFIRM_DISK_SWITCH = 'OVEHOSTED_UPGRADE/confirmDiskSwitch'
+
+    PREV_IMG_UUID = 'OVEHOSTED_UPGRADE/prevImgUUID'
+    PREV_VOL_UUID = 'OVEHOSTED_UPGRADE/prevVolUUID'
+
+
 # vim: expandtab tabstop=4 shiftwidth=4
